==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/listenbrainz/translations/listenbrainz_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>ListenBrainzFactory</name>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="30"/>
        <source>ListenBrainz Plugin</source>
        <translation>Estensione ListenBrainz</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="50"/>
        <source>About ListenBrainz Plugin</source>
        <translation>Informazioni sull&apos;estensione ListenBrainz</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="51"/>
        <source>Qmmp ListenBrainz Plugin</source>
        <translation>Estensione ListenBrainz per Qmmp</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="52"/>
        <source>This plugin submits listen history to ListenBrainz server</source>
        <translation>Estensione che invia la cronologia d&apos;ascolto al server ListenBrainz</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autori: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ListenBrainz Plugin Settings</source>
        <translation>Impostazioni dell&apos;estensione ListenBrainz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>ListenBrainz user token:</source>
        <translation>Token utente ListenBrainz:</translation>
    </message>
</context>
</TS>

==> qmmp_2.2.8.orig.tar.bz2: qmmp-2.2.8/src/plugins/General/listenbrainz/translations/listenbrainz_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>ListenBrainzFactory</name>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="30"/>
        <source>ListenBrainz Plugin</source>
        <translation>Estensione ListenBrainz</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="50"/>
        <source>About ListenBrainz Plugin</source>
        <translation>Informazioni sull&apos;estensione ListenBrainz</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="51"/>
        <source>Qmmp ListenBrainz Plugin</source>
        <translation>Estensione ListenBrainz per Qmmp</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="52"/>
        <source>This plugin submits listen history to ListenBrainz server</source>
        <translation>Estensione che invia la cronologia d&apos;ascolto al server ListenBrainz</translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autori: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>ListenBrainzSettingsDialog</name>
    <message>
        <location filename="../listenbrainzsettingsdialog.ui" line="14"/>
        <source>ListenBrainz Plugin Settings</source>
        <translation>Impostazioni dell&apos;estensione ListenBrainz</translation>
    </message>
    <message>
        <location filename="../listenbrainzsettingsdialog.ui" line="29"/>
        <source>ListenBrainz user token:</source>
        <translation>Token utente ListenBrainz:</translation>
    </message>
</context>
</TS>
